@@ -39,6 +39,10 @@
 #define SQL_XML -370
 #endif
 
+#ifndef SQL_DECFLOAT
+#define SQL_DECFLOAT -360
+#endif
+
 #ifndef SQL_ATTR_REPLACE_QUOTED_LITERALS
 #define SQL_ATTR_REPLACE_QUOTED_LITERALS 2586
 #endif
